#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-IeQo8kgXUWZFE25086RTRJ
key:                  persistent-test-2.13.1.3-IeQo8kgXUWZFE25086RTRJ
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  61b835e01576130f58fd2643b131d43d
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-IeQo8kgXUWZFE25086RTRJ
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-FUcewYgFPTwGfyjnEpPlTz
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1
    blaze-html-0.9.2.0-EgbbWPmo3205UQl3AObEBN bytestring-0.11.5.3
    conduit-1.3.6.1-GLye9k05ayiLdzpPDhJU0K containers-0.6.7
    exceptions-0.10.7 hspec-2.11.7-7U6fx3dsaNQ7EcGdmqSFJ7
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-B4xD2REm6ADDTbBWwdbcen
    monad-control-1.0.3.1-AyLS3fy4bfYGEyKgKmmIpm
    monad-logger-0.3.42-CtEWXmRQcRS9Y13lEQuG7v mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.6.0-3kQR514rtT0CT79v4LQQXd
    quickcheck-instances-0.3.33-4w3csCL9xx3A20YUmBmdgD
    random-1.2.1.3-1S1SEs3xtKIgpnjewCuMr
    resourcet-1.2.6-2ZRVpZAaCnB5eaGpQGOamD text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-HZAxHvexxnqDnog08LgNq2
    unliftio-0.2.25.1-8EuOvwMQbnH3C5Rgo2gyOI
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

